==> fmms_0.1.0.tar.gz: fmms-0.1.0/src/opt/fmms/fmms_sender_ui.py <==
#!/usr/bin/env python2.5
# -*- coding: utf-8 -*-
""" UI for fMMS

@author: Nick Leppänen Larsson <frals@frals.se>
@license: GNU GPL
"""
import gtk
import hildon
import os
import time
import gobject
import socket
from wappushhandler import MMSSender
import osso
import fmms_config as fMMSconf
import Image

class fMMS_GUI(hildon.Program):
	def __init__(self):
		hildon.Program.__init__(self)
		program = hildon.Program.get_instance()
		
		self.config = fMMSconf.fMMS_config()
		
		self.window = hildon.StackableWindow()
		self.window.set_title("fMMS - New MMS")
		program.add_window(self.window)
		
		self.window.connect("delete_event", self.quit)
		
		
		
		pan = hildon.PannableArea()
		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
		
		
		allBox = gtk.VBox()
		
		""" Begin top section """
		topHBox1 = gtk.HBox()
		
		bTo = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "     To     ")
		self.eNumber = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
		
		#topHBox.add(bTo)
		#topHBox.add(eNumber)
		topHBox1.pack_start(bTo, False, True, 0)
		topHBox1.pack_start(self.eNumber, True, True, 0)
		
		""" Ugly quick hack """
		"""topHBox2 = gtk.HBox()
		
		bFrom = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "YOURNUMBER")
		self.fNumber = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
		
		topHBox2.pack_start(bFrom, False, True, 0)
		topHBox2.pack_start(self.fNumber, True, True, 0)"""
		
		""" Begin midsection """
		midHBox = gtk.HBox()
		self.tvMessage = hildon.TextView()
		
		midHBox.pack_start(self.tvMessage, True, True, 0)
		
		""" Begin botsection """
		
		botHBox = gtk.HBox()
		#self.bAttachment = gtk.FileChooserButton('')
		#self.bAttachment.connect('file-set', self.update_size)
		self.bAttachment = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "Attachment")
		self.bAttachment.connect('clicked', self.open_file_dialog)
		
		self.lSize = gtk.Label('')
		
		self.bSend = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "    Send    ")
		self.bSend.connect('clicked', self.send_mms)
		
		botHBox.pack_start(self.bAttachment)
		botHBox.pack_start(self.lSize)
		botHBox.pack_end(self.bSend, False, False, 5)
		

		""" Show it all! """
		allBox.pack_start(topHBox1, False, False)
		#allBox.pack_start(topHBox2, False, False)
		allBox.pack_start(midHBox, True, True)
		allBox.pack_start(botHBox, False, False)
		
		pan.add_with_viewport(allBox)
		self.window.add(pan)
		self.window.show_all()
		self.add_window(self.window)
		
	def open_file_dialog(self, button):
		#fsm = hildon.FileSystemModel()
		#fcd = hildon.FileChooserDialog(self.window, gtk.FILE_CHOOSER_ACTION_OPEN, fsm)
		# this shouldnt issue a warning according to the pymaemo mailing list, but does
		# anyway, nfc why :(
		fcd = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_OPEN)
		fcd.set_default_response(gtk.RESPONSE_OK)
		ret = fcd.run()
		if ret == gtk.RESPONSE_OK:
			self.bAttachment.set_label(fcd.get_filename())
			self.update_size(fcd.get_filename())
			fcd.destroy()
		else:
			fcd.destroy()
	
	""" resize an image """
	""" thanks tomaszf for this function """
	""" slightly modified by frals """
	def resize_img(self, filename):
		try:
			if not os.path.isdir(self.config.get_imgdir()):
				print "creating dir", self.config.get_imgdir()
				os.makedirs(self.config.get_imgdir())
				
			img = Image.open(filename)
			print "height", img.size[1]
			print "width", img.size[0]
			newWidth = int(self.config.get_img_resize_width())
			if img.size[0] > newWidth:
				print "resizing"
				newWidth = int(self.config.get_img_resize_width())
				newHeight = int(newWidth * img.size[1] / img.size[0])
				print "Resizing image:", str(newWidth), "*", str(newHeight)

				# Image.BILINEAR, Image.BICUBIC, Image.ANTIALIASING
				rimg = img.resize((newWidth, newHeight), Image.BILINEAR)
				filename = filename.rpartition("/")
				filename = filename[-1]
				rattachment = self.config.get_imgdir() + filename
				rimg.save(rattachment)
				self.attachmentIsResized = True
			else:
				print "not resizing"
				rattachment = filename
				
			return rattachment
		
		except Exception, e:
			print "resizing failed:", e, e.args
			raise
	
	""" sends the message (no shit?) """
	def send_mms(self, widget):
		self.osso_c = osso.Context("fMMS", "0.1.0", False)
		
		attachment = self.bAttachment.get_label()
		if attachment == "Attachment":
			attachment = None
		print self.config.get_img_resize_width()
		self.attachmentIsResized = False
		if self.config.get_img_resize_width() != 0:
			try:
				attachment = self.resize_img(attachment)
			except Exception, e:
				print e, e.args
				note = osso.SystemNote(self.osso_c)
				errmsg = str(e.args)
				note.system_note_dialog("Resizing failed:\nError: " + errmsg , 'notice')
				raise
		
		to = self.eNumber.get_text()
		sender = self.config.get_phonenumber()
		tb = self.tvMessage.get_buffer()
		message = tb.get_text(tb.get_start_iter(), tb.get_end_iter())
		print sender, attachment, to, message

		""" Construct and send the message, off you go! """
		try:
			sender = MMSSender(to, "MMS", message, attachment, sender)
			(status, reason, output) = sender.sendMMS()
			### TODO: Clean up and make this look decent
			message = str(status) + "_" + str(reason) + "_" + str(output)
			message = message.replace('\0','')
			#print message
			banner = hildon.hildon_banner_show_information(widget, "", "MMSC REPLIED: " + message)
                        banner.set_timeout(5000)
		except TypeError, exc:
			#print type(exc)
			note = osso.SystemNote(self.osso_c)
			errmsg = "Invalid attachment"
			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure the file is valid" , 'notice')
			raise
		except socket.error, exc:
			#print type(exc)
			print exc
			code = str(exc.args[0])
			text = str(exc.args[1])
			note = osso.SystemNote(self.osso_c)
			errmsg = code + " " + text
			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure APN settings are correct" , 'notice')
			raise
		except Exception, exc:
			print type(exc)
			print exc
			raise
			
		if self.attachmentIsResized == True:
			print "Removing temporary image..."
			os.remove(attachment)
	
		
	def update_size(self, fname):
		try:
			size = os.path.getsize(fname) / 1024
			self.lSize.set_markup("Size:\n<small>" + str(size) + "kB</small>")	
		except TypeError:
			self.lSize.set_markup("")

	def quit(self, *args):
		gtk.main_quit()

	def run(self):
		self.window.show_all()
		gtk.main()
		
if __name__ == "__main__":
	app = fMMS_GUI()
	app.run()

==> fmms_0.1.3.tar.gz: fmms-0.1.3/src/opt/fmms/fmms_sender_ui.py <==
#!/usr/bin/env python2.5
# -*- coding: utf-8 -*-
""" UI for fMMS

@author: Nick Leppänen Larsson <frals@frals.se>
@license: GNU GPL
"""
import gtk
import hildon
import os
import time
import gobject
import socket
from wappushhandler import MMSSender
import osso
import fmms_config as fMMSconf
import Image

class fMMS_GUI(hildon.Program):
	def __init__(self):
		hildon.Program.__init__(self)
		program = hildon.Program.get_instance()
		
		self.config = fMMSconf.fMMS_config()
		
		self.window = hildon.StackableWindow()
		self.window.set_title("fMMS - New MMS")
		program.add_window(self.window)
		
		self.window.connect("delete_event", self.quit)
		
		
		
		pan = hildon.PannableArea()
		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
		
		
		allBox = gtk.VBox()
		
		""" Begin top section """
		topHBox1 = gtk.HBox()
		
		bTo = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "     To     ")
		self.eNumber = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
		
		#topHBox.add(bTo)
		#topHBox.add(eNumber)
		topHBox1.pack_start(bTo, False, True, 0)
		topHBox1.pack_start(self.eNumber, True, True, 0)
		
		""" Ugly quick hack """
		"""topHBox2 = gtk.HBox()
		
		bFrom = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "YOURNUMBER")
		self.fNumber = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
		
		topHBox2.pack_start(bFrom, False, True, 0)
		topHBox2.pack_start(self.fNumber, True, True, 0)"""
		
		""" Begin midsection """
		midHBox = gtk.HBox()
		self.tvMessage = hildon.TextView()
		
		midHBox.pack_start(self.tvMessage, True, True, 0)
		
		""" Begin botsection """
		
		botHBox = gtk.HBox()
		#self.bAttachment = gtk.FileChooserButton('')
		#self.bAttachment.connect('file-set', self.update_size)
		self.bAttachment = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "Attachment")
		self.bAttachment.connect('clicked', self.open_file_dialog)
		
		self.lSize = gtk.Label('')
		
		self.bSend = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "    Send    ")
		self.bSend.connect('clicked', self.send_mms)
		
		botHBox.pack_start(self.bAttachment)
		botHBox.pack_start(self.lSize)
		botHBox.pack_end(self.bSend, False, False, 5)
		

		""" Show it all! """
		allBox.pack_start(topHBox1, False, False)
		#allBox.pack_start(topHBox2, False, False)
		allBox.pack_start(midHBox, True, True)
		allBox.pack_start(botHBox, False, False)
		
		pan.add_with_viewport(allBox)
		self.window.add(pan)
		self.window.show_all()
		self.add_window(self.window)
		
	def open_file_dialog(self, button):
		#fsm = hildon.FileSystemModel()
		#fcd = hildon.FileChooserDialog(self.window, gtk.FILE_CHOOSER_ACTION_OPEN, fsm)
		# this shouldnt issue a warning according to the pymaemo mailing list, but does
		# anyway, nfc why :(
		fcd = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_OPEN)
		fcd.set_default_response(gtk.RESPONSE_OK)
		ret = fcd.run()
		if ret == gtk.RESPONSE_OK:
			self.bAttachment.set_label(fcd.get_filename())
			self.update_size(fcd.get_filename())
			fcd.destroy()
		else:
			fcd.destroy()
	
	""" resize an image """
	""" thanks tomaszf for this function """
	""" slightly modified by frals """
	def resize_img(self, filename):
		try:
			if not os.path.isdir(self.config.get_imgdir()):
				print "creating dir", self.config.get_imgdir()
				os.makedirs(self.config.get_imgdir())
				
			img = Image.open(filename)
			print "height", img.size[1]
			print "width", img.size[0]
			newWidth = int(self.config.get_img_resize_width())
			if img.size[0] > newWidth:
				print "resizing"
				newWidth = int(self.config.get_img_resize_width())
				newHeight = int(newWidth * img.size[1] / img.size[0])
				print "Resizing image:", str(newWidth), "*", str(newHeight)

				# Image.BILINEAR, Image.BICUBIC, Image.ANTIALIASING
				rimg = img.resize((newWidth, newHeight), Image.BILINEAR)
				filename = filename.rpartition("/")
				filename = filename[-1]
				rattachment = self.config.get_imgdir() + filename
				rimg.save(rattachment)
				self.attachmentIsResized = True
			else:
				print "not resizing"
				rattachment = filename
				
			return rattachment
		
		except Exception, e:
			print "resizing failed:", e, e.args
			raise
	
	""" sends the message (no shit?) """
	def send_mms(self, widget):
		self.osso_c = osso.Context("fMMS", "0.1.0", False)
		
		attachment = self.bAttachment.get_label()
		if attachment == "Attachment" or attachment == None:
			attachment = None
		else:
			print attachment
			print self.config.get_img_resize_width()
			self.attachmentIsResized = False
			if self.config.get_img_resize_width() != 0:
				try:
					attachment = self.resize_img(attachment)
				except Exception, e:
					print e, e.args
					note = osso.SystemNote(self.osso_c)
					errmsg = str(e.args)
					note.system_note_dialog("Resizing failed:\nError: " + errmsg , 'notice')
					raise
		
		to = self.eNumber.get_text()
		sender = self.config.get_phonenumber()
		tb = self.tvMessage.get_buffer()
		message = tb.get_text(tb.get_start_iter(), tb.get_end_iter())
		print sender, attachment, to, message

		""" Construct and send the message, off you go! """
		try:
			sender = MMSSender(to, "MMS", message, attachment, sender)
			(status, reason, output) = sender.sendMMS()
			### TODO: Clean up and make this look decent
			message = str(status) + "_" + str(reason) + "_" + str(output)
			message = message.replace('\0','')
			#print message
			banner = hildon.hildon_banner_show_information(widget, "", "MMSC REPLIED: " + message)
                        banner.set_timeout(5000)
		except TypeError, exc:
			#print type(exc)
			note = osso.SystemNote(self.osso_c)
			errmsg = "Invalid attachment"
			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure the file is valid" , 'notice')
			raise
		except socket.error, exc:
			#print type(exc)
			print exc
			code = str(exc.args[0])
			text = str(exc.args[1])
			note = osso.SystemNote(self.osso_c)
			errmsg = code + " " + text
			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure APN settings are correct" , 'notice')
			raise
		except Exception, exc:
			print type(exc)
			print exc
			raise
			
		if self.attachmentIsResized == True:
			print "Removing temporary image..."
			os.remove(attachment)
	
		
	def update_size(self, fname):
		try:
			size = os.path.getsize(fname) / 1024
			self.lSize.set_markup("Size:\n<small>" + str(size) + "kB</small>")	
		except TypeError:
			self.lSize.set_markup("")

	def quit(self, *args):
		gtk.main_quit()

	def run(self):
		self.window.show_all()
		gtk.main()
		
if __name__ == "__main__":
	app = fMMS_GUI()
	app.run()
